@@ -4,9 +4,9 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-use Module::Metadata;
+use Module::Metadata 1.000005;
 
 use Moose;
 
@@ -52,7 +52,7 @@ Dist::Zilla::Plugin::VersionFromMainModule - Set the distribution version from y
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
